# emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
# vi: set ft=python sts=4 ts=4 sw=4 et:
"""

Using the classifier
--------------------

.. toctree::
    :maxdepth: 3

    cv/base
    cv/data
    cv/helper

Cross-validation in MRIQC
-------------------------

.. toctree::
    :maxdepth: 3

    cv/experiments

"""
